@@ -45,7 +45,7 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
     self.__sai_cacher = DITPixbufCacher(18)
     self.__sai_animator = DITPBCachedAnimator([], self.set_status_area_icon, 
                                               cacher=self.__sai_cacher, 
-                                              time_out=1000)
+                                              time_out=2000)
     self.__m_loop = DBusGMainLoop()
     self.__bus = dbus.SystemBus(mainloop = self.__m_loop, private = True)
 
@@ -76,7 +76,7 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
 
   def __show_settings_dialog(self, button=None):
     self.__config.load()
-    settings_dialog = gtk.Dialog(self.app_name, None, 
+    settings_dialog = gtk.Dialog(self.app_name, None,#self.window, 
                                  gtk.DIALOG_MODAL | gtk.DIALOG_NO_SEPARATOR, 
                                  self.__config_ui.get_dialog_buttons())
     wpa = gtk.VBox()
