@@ -70,7 +70,8 @@ class AbstractInterface():
 
     #print self.__name, self.state['value'], self.state['mode'], self.state['strength']
     #self.__show_switch_dialog()
-
+    #self.__show_switch_dialog()
+    
   def pre_init(self):
     pass
 
@@ -147,15 +148,18 @@ class AbstractInterface():
       self.state['value'] = value
       show_banner = True
       update_ui = True
-      if self.state_control: self.state_control.set_active(value)
+      if self.state_control:
+        self.state_control.set_active(value)
     if mode != None and mode != self.state['mode']:
       self.state['mode'] = mode
       show_banner = True
-      if self.mode_control: self.mode_control.set_active(mode)
+      if self.mode_control:
+        self.mode_control.set_active(mode)
     if strength != None and strength != self.state['strength']:
       self.state['strength'] = strength
       update_ui = True
-    if update_ui: self.__update_ui()
+    if update_ui:
+      self.__update_ui()
     windex = self.state['value']
     if self.get_config_value('show-popups') and show_banner and self.state['banner'][windex]:
       text = '%s: %s' % \
@@ -238,7 +242,7 @@ class AbstractInterface():
     return True
 
   def __show_switch_dialog(self):
-    settings_dialog = gtk.Dialog('%s' % (self.__name), None, 
+    settings_dialog = gtk.Dialog('%s' % (self.__name), None,#self.__button.window, 
                                  gtk.DIALOG_MODAL | gtk.DIALOG_NO_SEPARATOR, 
                                  (gtk.STOCK_PREFERENCES, gtk.RESPONSE_OK))
     self.state_control = ToggleControlMaemo5(self.__get_state_controls())
@@ -258,6 +262,14 @@ class AbstractInterface():
     #settings_dialog.vbox.set_size_request(-1, min(350, height))
     settings_dialog.show_all()
     self.__processing = False
+    response = settings_dialog.run()
+    if response == gtk.RESPONSE_DELETE_EVENT:
+      settings_dialog.destroy()
+      self.state_control.destroy()
+      self.state_control = None
+      if self.mode_control:
+        self.mode_control.destroy()
+        self.mode_control = None
 
   def __get_state_controls(self):
     texts = map(self.__lcl.get_item, list(self.state['text']))
